pub struct QueryProofCircuitInput<const MAX_DEPTH: usize> {
pub pk: [EdwardsAffine; 7],
pub pk_index: Fq,
pub s: Fr,
pub r: EdwardsAffine,
pub merkle_root: Fq,
pub depth: Fq,
pub mt_index: Fq,
pub siblings: [Fq; MAX_DEPTH],
pub beta: Fr,
pub rp_id: Fq,
pub action: Fq,
pub nonce: Fq,
}Expand description
The input for the circuit of the OPRF Query Proof π1.
TODO: Rename attribute names to match the Credential type.
Fields
pk: [EdwardsAffine; 7]The AuthenticatorPublicKeySet represented as an array of Affine points.
pk_index: FqThe index of the public key which will be used to sign the OPRF query from the AuthenticatorPublicKeySet.
s: FrThe s part of the signature of the query with the public key at the pk_index.
r: EdwardsAffineThe r part of the signature of the query with the public key at the pk_index.
merkle_root: FqThe root of the Merkle tree of the WorldIDRegistry contract.
depth: FqThe depth of the Merkle tree of the WorldIDRegistry contract.
mt_index: FqThe leaf index of the World ID in the Merkle tree of the WorldIDRegistry contract.
In the MerkleInclusionProof type, this is the leaf_index field.
siblings: [Fq; MAX_DEPTH]The siblings of the Merkle proof of the account in the WorldIDRegistry contract.
beta: FrThe (non-inverted) blinding factor of the OPRF query.
rp_id: FqThe ID of the RP requesting the proof as registered in the RpRegistry contract.
TODO: Will require updates once the new RpRegistry is launched.
action: FqThe action for the proof request. See ProofRequest for more details.
nonce: FqThe nonce of the proof request. See ProofRequest for more details.