pub struct OprfNullifier {
pub query_proof_input: QueryProofCircuitInput<TREE_DEPTH>,
pub verifiable_oprf_output: VerifiableOprfOutput,
pub nullifier: Nullifier,
}Expand description
Nullifier computed using OPRF Nodes.
Fields
query_proof_input: QueryProofCircuitInput<TREE_DEPTH>The raw inputs to the Query Proof circuit
verifiable_oprf_output: VerifiableOprfOutputThe result of the distributed OPRF protocol.
nullifier: NullifierThe final nullifier value to be used in a Proof.
This is equal to VerifiableOprfOutput::output and is already unblinded.
Implementations
Sourceimpl OprfNullifier
impl OprfNullifier
Sourcepub async fn generate(
services: &[String],
threshold: usize,
query_material: &CircomGroth16Material,
authenticator_input: AuthenticatorProofInput,
proof_request: &ProofRequest,
connector: Connector,
) -> Result<Self, ProofError>
pub async fn generate( services: &[String], threshold: usize, query_material: &CircomGroth16Material, authenticator_input: AuthenticatorProofInput, proof_request: &ProofRequest, connector: Connector, ) -> Result<Self, ProofError>
Generates a nullifier through the provided OPRF nodes for a specific proof request.
This method will handle the signature from the Authenticator authorizing the request for the OPRF nodes.
Arguments
services: The list of endpoints of all OPRF nodes.threshold: The minimum number of OPRF nodes responses required to compute a valid nullifier. The source of truth for this value lives in theOprfKeyRegistrycontract.query_material: The material for the query proof circuit.authenticator_input: SeeAuthenticatorProofInputfor more details.proof_request: The proof request provided by the RP.
Errors
Returns ProofError in the following cases:
PublicKeyNotFound- the public key for the given authenticator private key is not found in thekey_set.InvalidDLogProof– theDLogequality proof could not be verified.- Other errors may propagate from network requests, proof generation, or Groth16 verification.