pub enum ZkeyError {
ZkeyFingerprintMismatch(String),
GraphFingerprintMismatch(String),
ZkeyInvalid(Report),
GraphInvalid(Report),
IoError(Error),
}Expand description
Errors that can occur while loading or parsing a .zkey or graph file.
Variants
ZkeyFingerprintMismatch(String)
The SHA-256 fingerprint of the .zkey did not match the expected value.
GraphFingerprintMismatch(String)
The SHA-256 fingerprint of the witness graph did not match the expected value.
ZkeyInvalid(Report)
Could not parse the .zkey file.
GraphInvalid(Report)
Could not parse the graph file.
IoError(Error)
Any I/O error encountered while reading the .zkey or graph file