This module contains error types and validation functions for World ID proof inputs.
These are intended to assist in producing more helpful error messages for a given proof. If the circuits change in any way, these checks may also need to be updated to match the new logic.
Enums
- Proof
Input Error - Errors that can occur when validating the inputs for a single World ID proof.
Functions
- check_
nullifier_ input_ validity - This method checks the validity of the input parameters by emulating the operations that are proved in ZK and raising Errors that would result in an invalid proof.
- check_
query_ input_ validity - This method checks the validity of the input parameters by emulating the operations that are proved in ZK and raising Errors that would result in an invalid proof.