pub enum ProofInputError {
Show 13 variants
InvalidMerkleTreeDepth {
expected: usize,
is: Fq,
},
InvalidAuthenticatorPublicKeySet,
InvalidMerkleTreeInclusionProof,
InvalidQuerySignature,
InvalidBlindingFactor,
CredentialExpired {
current_timestamp: u64,
expires_at: u64,
},
CredentialGenesisExpired {
genesis_issued_at_min: u64,
genesis_issued_at: u64,
},
ValueOutOfBounds {
name: &'static str,
is: Fq,
limit: Fq,
},
InvalidCredentialSignature,
InvalidBabyJubJubPoint {
name: &'static str,
},
InvalidOprfProof,
InvalidOprfResponse,
InvalidSessionId,
}Expand description
Errors that can occur when validating the inputs for a single World ID proof.
Variants
InvalidMerkleTreeDepth
The specified Merkle tree depth is invalid.
InvalidAuthenticatorPublicKeySet
The set of authenticator public keys is invalid.
InvalidMerkleTreeInclusionProof
The provided Merkle tree inclusion proof is invalid (the root may or may not be valid for the WorldIDRegistry tree)
InvalidQuerySignature
The signature from the authenticator for the request is invalid.
InvalidBlindingFactor
The provided blinding factor is invalid, or the sub is incorrect.
CredentialExpired
The provided credential has expired.
CredentialGenesisExpired
The provided credential genesis issue timestamp is expired.
Fields
ValueOutOfBounds
A value is out of bounds.
Fields
InvalidCredentialSignature
The credential signature is invalid. This signals the issued credential is invalid.
InvalidBabyJubJubPoint
The provided point is not a valid point in the prime-order subgroup of the BabyJubJub curve.
InvalidOprfProof
The provided OPRF proof is invalid.
InvalidOprfResponse
The provided unblinded OPRF response point is invalid.
InvalidSessionId
The provided session ID commitment is invalid.