check_query_input_validity

Function check_query_input_validity 

pub fn check_query_input_validity<const TREE_DEPTH: usize>(
    inputs: &QueryProofCircuitInput<TREE_DEPTH>,
) -> Result<EdwardsAffine, ProofInputError>
This method checks the validity of the input parameters by emulating the operations that are proved in ZK and raising Errors that would result in an invalid proof.

Returns the blinded OPRF query point if everything is ok.

Errors

This function will return a ProofInputError if any of the checks fail. The Display implementation of this error can be used to get a human-readable error message on which parts of the input were invalid.