load_embedded_nullifier_material

Function load_embedded_nullifier_material 

pub fn load_embedded_nullifier_material() -> Result<CircomGroth16Material>
Loads the CircomGroth16Material for the uniqueness proof (internally also nullifier proof) from the embedded keys in the binary without caching.

Returns

The nullifier material.

Errors

Will return an error if the zkey file cannot be loaded.