load_embedded_query_material

Function load_embedded_query_material 

pub fn load_embedded_query_material() -> Result<CircomGroth16Material>
Loads the CircomGroth16Material for the uniqueness proof (internally also query proof) from the optional zkey file or from embedded keys in the binary.

Returns

The query material

Errors

Will return an error if the zkey file cannot be loaded.