ProofInputError

Enum ProofInputError 

pub enum ProofInputError {
Show 13 variants InvalidMerkleTreeDepth { expected: usize, is: Fq, }, InvalidAuthenticatorPublicKeySet, InvalidMerkleTreeInclusionProof, InvalidQuerySignature, InvalidBlindingFactor, CredentialExpired { current_timestamp: u64, expires_at: u64, }, CredentialGenesisExpired { genesis_issued_at_min: u64, genesis_issued_at: u64, }, ValueOutOfBounds { name: &'static str, is: Fq, limit: Fq, }, InvalidCredentialSignature, InvalidBabyJubJubPoint { name: &'static str, }, InvalidOprfProof, InvalidOprfResponse, InvalidSessionId,
}
Errors that can occur when validating the inputs for a single World ID proof.

Variants



InvalidMerkleTreeDepth

The specified Merkle tree depth is invalid.

Fields

expected: usize

Expected depth.

is: Fq

Actual depth.



InvalidAuthenticatorPublicKeySet

The set of authenticator public keys is invalid.



InvalidMerkleTreeInclusionProof

The provided Merkle tree inclusion proof is invalid (the root may or may not be valid for the WorldIDRegistry tree)



InvalidQuerySignature

The signature from the authenticator for the request is invalid.



InvalidBlindingFactor

The provided blinding factor is invalid, or the sub is incorrect.



CredentialExpired

The provided credential has expired.

Fields

current_timestamp: u64

Current timestamp.

expires_at: u64

Expiration timestamp.



CredentialGenesisExpired

The provided credential genesis issue timestamp is expired.

Fields

genesis_issued_at_min: u64

Minimum Issue date.

genesis_issued_at: u64

Genesis issue timestamp.



ValueOutOfBounds

A value is out of bounds.

Fields

name: &'static str

Name of the value for error message.

is: Fq

Actual value.

limit: Fq

Upper limit, not inclusive.



InvalidCredentialSignature

The credential signature is invalid. This signals the issued credential is invalid.



InvalidBabyJubJubPoint

The provided point is not a valid point in the prime-order subgroup of the BabyJubJub curve.

Fields

name: &'static str

Name of the point for error message.



InvalidOprfProof

The provided OPRF proof is invalid.



InvalidOprfResponse

The provided unblinded OPRF response point is invalid.



InvalidSessionId

The provided session ID commitment is invalid.