pub fn load_nullifier_material_from_paths(
zkey: impl AsRef<Path>,
graph: impl AsRef<Path>,
) -> CircomGroth16MaterialExpand description
Loads the CircomGroth16Material for the nullifier proof from the provided paths.
Panics
Will panic if the material cannot be loaded or verified.