pub fn load_query_material_from_reader(
zkey: impl Read,
graph: impl Read,
) -> Result<CircomGroth16Material>Expand description
Loads the CircomGroth16Material for the query proof from the provided reader.
Errors
Will return an error if the material cannot be loaded or verified.